
delphin.sembase
===============

.. automodule:: delphin.sembase

   Module Functions
   ----------------

   .. autofunction:: role_priority
   .. autofunction:: property_priority

   Classes
   -------

   .. autoclass:: Predication
      :show-inheritance:
      :members:

   .. autoclass:: SemanticStructure
      :show-inheritance:
      :members:
